function [evaluacion, R_N] = mi_ln(x, N)
    % MI_LN Calcula el logaritmo natural de x usando su serie de Taylor en a = 1.
    %
    % Entradas:
    %   x : Valor en el cual se evalúa ln(x). (Recomendado: 0 < x <= 2)
    %   N : Número de términos a sumar en la serie.
    %
    % Salidas:
    %   evaluacion : Valor aproximado de ln(x) usando N términos.
    %   R_N        : Estimación del error de truncamiento (primer término omitido).

    % Validar rango de convergencia sugerido
    if x <= 0 || x > 2
        warning('La serie de Taylor centrada en a=1 diverge para x fuera de (0, 2].');
    end

    % Inicializar la suma
    evaluacion = 0;

    % 1. Sumatoria de N términos
    for n = 1:N
        termino = ((-1)^(n-1) / n) * (x - 1).^n;
        evaluacion = evaluacion + termino;
    end

    % 2. Estimación del Error de Truncamiento R_N(x)
    % Se calcula como el primer término omitido (término N+1)
    n_siguiente = N + 1;
    R_N = ((-1)^(n_siguiente-1) / n_siguiente) * (x - 1).^n_siguiente;
end
